|PyPI| |Docs|

.. |PyPI| image:: https://img.shields.io/pypi/v/scanpy.svg
   :target: https://pypi.org/project/scRFE/
.. |Docs| image:: https://readthedocs.com/projects/icb-scanpy/badge/?version=latest
   :target: https://scRFE.readthedocs.io/en/latest/index.html


scRFE (single-cell identity definition using random forest modelling and recursive feature elimination)
============================================================================================================
scRFE is a python package that uses a one versus all random forest classifier with recursive feature elimination to identify the set of genes necessary and sufficient to describe the different features of your single-cell RNA sequencing data.

.. toctree::
   :maxdepth: 1
   :hidden:


   introduction
   howtousescrfe
   installingscrfe
